@@ -9,8 +9,7 @@ import matplotlib.ticker as mticker
 from rl_plotter import plot_utils as pu
 
 
-if __name__ == "__main__":
-	
+def main():
 	parser = argparse.ArgumentParser(description='plotter')
 	parser.add_argument('--fig_length', type=int, default=6, 
 						help='matplotlib figure length (default: 6)')
@@ -26,8 +25,8 @@ if __name__ == "__main__":
 						help='x-axis key in csv file (default: l)')
 	parser.add_argument('--ykey', default='r',
 						help='y-axis key in csv file (default: r)')
-	parser.add_argument('--smooth', type=int, default=0,
-						help='smooth radius of y axis (default: 1)')
+	parser.add_argument('--smooth', type=int, default=10,
+						help='smooth radius of y axis (default: 10)')
 	parser.add_argument('--ylabel', default=None,
 						help='matplotlib figure ylabel')
 	parser.add_argument('--avg_group', action='store_true',
@@ -51,8 +50,8 @@ if __name__ == "__main__":
 	parser.add_argument('--xlim', type=int, default=None,
 						help='x-axis limitation (default: None)')
 	
-	parser.add_argument('--log_dir', default='./logs/',
-						help='log dir (default: ./logs/)')
+	parser.add_argument('--log_dir', default='./',
+						help='log dir (default: ./)')
 	parser.add_argument('--filename', default='monitor',
 						help='csv filename')
 	parser.add_argument('--show', action='store_true',
@@ -117,4 +116,8 @@ if __name__ == "__main__":
 	if args.save:
 		plt.savefig(args.log_dir + 'figure', dpi=args.dpi, bbox_inches='tight')
 	if args.show:
-		plt.show()
\ No newline at end of file
+		plt.show()
+
+
+if __name__ == "__main__":
+	main()
\ No newline at end of file
